@@ -23,10 +23,7 @@
 #include "IntSet.h"
 #include "Wikidiff2.h"
 #include "Word.h"
-#include "textutil.h"
-#ifdef HHVM_BUILD_DSO
-#include "hphp/runtime/base/ini-setting.h"
-#endif //HHVM_BUILD_DSO
+#include "TextUtil.h"
 
 // Default value for INI setting wikidiff2.change_threshold
 #define WIKIDIFF2_CHANGE_THRESHOLD_DEFAULT		"0.2"
@@ -158,7 +155,10 @@ class DiffEngine
 		typedef std::set<T, std::less<T>, WD2_ALLOCATOR<T> > ValueSet;
 #endif
 
-		DiffEngine() : done(false) {}
+		DiffEngine()
+			: done(false), textUtil(TextUtil::getInstance())
+		{}
+
 		void clear();
 		void diff (const ValueVector & from_lines,
 				const ValueVector & to_lines, Diff<T> & diff,
@@ -171,6 +171,7 @@ class DiffEngine
 		int diag (int xoff, int xlim, int yoff, int ylim, int nchunks,
 				IntPairVector & seps);
 
+		TextUtil & textUtil;
 		BoolVector xchanged, ychanged;
 		PointerVector xv, yv;
 		IntVector xind, yind;
@@ -203,44 +204,20 @@ void DiffEngine<T>::clear()
 
 inline double characterSimilarityThreshold()
 {
-#ifdef HHVM_BUILD_DSO
-	// HHVM module
-	HPHP::Variant value(WIKIDIFF2_CHANGE_THRESHOLD_DEFAULT);
-	HPHP::IniSetting::Get(std::string("wikidiff2.change_threshold"), value);
-	return value.toDouble();
-#else
-	// Zend module
 	double ret = INI_FLT("wikidiff2.change_threshold");
 	return ret;
-#endif //HHVM_BUILD_DSO
 }
 
 inline double movedLineThreshold()
 {
-#ifdef HHVM_BUILD_DSO
-	// HHVM module
-	HPHP::Variant value(WIKIDIFF2_MOVED_LINE_THRESHOLD_DEFAULT);
-	HPHP::IniSetting::Get(std::string("wikidiff2.moved_line_threshold"), value);
-	return value.toDouble();
-#else
-	// Zend module
 	double ret = INI_FLT("wikidiff2.moved_line_threshold");
 	return ret;
-#endif //HHVM_BUILD_DSO
 }
 
 inline int movedParagraphDetectionCutoff()
 {
-#ifdef HHVM_BUILD_DSO
-	// HHVM module
-	HPHP::Variant value(WIKIDIFF2_MOVED_PARAGRAPH_DETECTION_CUTOFF_DEFAULT);
-	HPHP::IniSetting::Get(std::string("wikidiff2.moved_paragraph_detection_cutoff"), value);
-	return value.toInt32();
-#else
-	// Zend module
 	int ret = INI_INT("wikidiff2.moved_paragraph_detection_cutoff");
 	return ret;
-#endif //HHVM_BUILD_DSO
 }
 
 // for a DiffOp::change, decide whether it should be treated as a successive add and delete based on similarity.
@@ -248,8 +225,8 @@ template<typename T>
 inline bool DiffEngine<T>::looksLikeChange(const T& del, const T& add, long long bailoutComplexity)
 {
 	TextUtil::WordVector words1, words2;
-	TextUtil::explodeWords(del, words1);
-	TextUtil::explodeWords(add, words2);
+	textUtil.explodeWords(del, words1);
+	textUtil.explodeWords(add, words2);
 	WordDiffStats ds(words1, words2, bailoutComplexity);
 	return ds.charSimilarity > characterSimilarityThreshold();
 }
