@@ -1,6 +1,7 @@
 #include "InlineDiff.h"
 
-void InlineDiff::printAdd(const String& line)
+void InlineDiff::printAdd(const String& line, int leftLine, int rightLine, int offsetFrom,
+	int offsetTo)
 {
 	if(line.empty()) {
 		printWrappedLine("<div class=\"mw-diff-inline-added mw-diff-empty-line\"><ins>", line, "</ins></div>\n");
@@ -9,7 +10,8 @@ void InlineDiff::printAdd(const String& line)
 	}
 }
 
-void InlineDiff::printDelete(const String& line)
+void InlineDiff::printDelete(const String& line, int leftLine, int rightLine,
+	int offsetFrom, int offsetTo)
 {
 	if(line.empty()) {
 		printWrappedLine("<div class=\"mw-diff-inline-deleted mw-diff-empty-line\"><del>", line, "</del></div>\n");
@@ -18,12 +20,14 @@ void InlineDiff::printDelete(const String& line)
 	}
 }
 
-void InlineDiff::printWordDiff(const String& text1, const String& text2, bool printLeft, bool printRight, const String & srcAnchor, const String & dstAnchor, bool moveDirectionDownwards)
+void InlineDiff::printWordDiff(const String& text1, const String& text2, int leftLine, int rightLine,
+	int offsetFrom, int offsetTo, bool printLeft, bool printRight,
+	const String & srcAnchor, const String & dstAnchor, bool moveDirectionDownwards)
 {
 	WordVector words1, words2;
 
-	TextUtil::explodeWords(text1, words1);
-	TextUtil::explodeWords(text2, words2);
+	textUtil.explodeWords(text1, words1);
+	textUtil.explodeWords(text2, words2);
 	WordDiff worddiff(words1, words2, MAX_WORD_LEVEL_DIFF_COMPLEXITY);
 	String word;
 
@@ -52,7 +56,7 @@ void InlineDiff::printWordDiff(const String& text1, const String& text2, bool pr
 			n = op.from.size();
 			for (j=0; j<n; j++) {
 				op.from[j]->get_whole(word);
-				printText(word);
+				printHtmlEncodedText(word);
 			}
 		} else if (op.op == DiffOp<Word>::del) {
 			n = op.from.size();
@@ -60,7 +64,7 @@ void InlineDiff::printWordDiff(const String& text1, const String& text2, bool pr
 				result += "<del>";
 			for (j=0; j<n; j++) {
 				op.from[j]->get_whole(word);
-				printText(word);
+				printHtmlEncodedText(word);
 			}
 			if (!isMoveSrc)
 				result += "</del>";
@@ -71,7 +75,7 @@ void InlineDiff::printWordDiff(const String& text1, const String& text2, bool pr
 			result += "<ins>";
 			for (j=0; j<n; j++) {
 				op.to[j]->get_whole(word);
-				printText(word);
+				printHtmlEncodedText(word);
 			}
 			result += "</ins>";
 		} else if (op.op == DiffOp<Word>::change) {
@@ -80,7 +84,7 @@ void InlineDiff::printWordDiff(const String& text1, const String& text2, bool pr
 				result += "<del>";
 			for (j=0; j<n; j++) {
 				op.from[j]->get_whole(word);
-				printText(word);
+				printHtmlEncodedText(word);
 			}
 			if (isMoveSrc)
 				continue;
@@ -89,7 +93,7 @@ void InlineDiff::printWordDiff(const String& text1, const String& text2, bool pr
 			result += "<ins>";
 			for (j=0; j<n; j++) {
 				op.to[j]->get_whole(word);
-				printText(word);
+				printHtmlEncodedText(word);
 			}
 			result += "</ins>";
 		}
@@ -111,7 +115,8 @@ void InlineDiff::printBlockHeader(int leftLine, int rightLine)
 	result += buf;
 }
 
-void InlineDiff::printContext(const String & input)
+void InlineDiff::printContext(const String & input, int leftLine, int rightLine,
+	int offsetFrom, int offsetTo)
 {
 	printWrappedLine("<div class=\"mw-diff-inline-context\">", input, "</div>\n");
 }
@@ -122,7 +127,7 @@ void InlineDiff::printWrappedLine(const char* pre, const String& line, const cha
 	if (line.empty()) {
 		result += "&#160;";
 	} else {
-		printText(line);
+		printHtmlEncodedText(line);
 	}
 	result += post;
 }
