@@ -7,31 +7,41 @@
 #include "php.h"
 #include "php_ini.h"
 #include "ext/standard/info.h"
+#include "zend_API.h"
 #include "php_wikidiff2.h"
 #include "Wikidiff2.h"
 #include "TableDiff.h"
 #include "InlineDiff.h"
+#include "InlineDiffJSON.h"
 
-#if PHP_MAJOR_VERSION >= 7
-#define COMPAT_RETURN_STRINGL(s, l) { RETURN_STRINGL(s, l); return; }
+#if PHP_VERSION_ID >= 80000
+#	include "wikidiff2_arginfo.h"
 #else
-#define COMPAT_RETURN_STRINGL(s, l) { RETURN_STRINGL(s, l, 1); return; }
+#	define arginfo_wikidiff2_do_diff NULL
+#	define arginfo_wikidiff2_inline_diff NULL
+#	define arginfo_wikidiff2_inline_json_diff NULL
+#	define arginfo_wikidiff2_version NULL
+#endif
+
+#define COMPAT_RETURN_STRINGL(s, l) { RETURN_STRINGL(s, l); return; }
+
+#if PHP_VERSION_ID < 70000
+#    error "PHP version 7 or later is required."
 #endif
 
 static int le_wikidiff2;
 
 zend_function_entry wikidiff2_functions[] = {
-	PHP_FE(wikidiff2_do_diff,     NULL)
-	PHP_FE(wikidiff2_inline_diff, NULL)
-	PHP_FE(wikidiff2_version, NULL)
+	PHP_FE(wikidiff2_do_diff, arginfo_wikidiff2_do_diff)
+	PHP_FE(wikidiff2_inline_diff, arginfo_wikidiff2_inline_diff)
+	PHP_FE(wikidiff2_inline_json_diff, arginfo_wikidiff2_inline_json_diff)
+	PHP_FE(wikidiff2_version, arginfo_wikidiff2_version)
 	{NULL, NULL, NULL}
 };
 
 
 zend_module_entry wikidiff2_module_entry = {
-#if ZEND_MODULE_API_NO >= 20010901
 	STANDARD_MODULE_HEADER,
-#endif
 	"wikidiff2",
 	wikidiff2_functions,
 	PHP_MINIT(wikidiff2),
@@ -39,9 +49,7 @@ zend_module_entry wikidiff2_module_entry = {
 	PHP_RINIT(wikidiff2),
 	PHP_RSHUTDOWN(wikidiff2),
 	PHP_MINFO(wikidiff2),
-#if ZEND_MODULE_API_NO >= 20010901
 	WIKIDIFF2_VERSION_STRING,
-#endif
 	STANDARD_MODULE_PROPERTIES
 };
 
@@ -97,17 +105,11 @@ PHP_FUNCTION(wikidiff2_do_diff)
 	char *text1 = NULL;
 	char *text2 = NULL;
 	int argc = ZEND_NUM_ARGS();
-#if PHP_MAJOR_VERSION >= 7
 	size_t text1_len;
 	size_t text2_len;
 	zend_long numContextLines;
-#else
-	int text1_len;
-	int text2_len;
-	long numContextLines;
-#endif
 
-	if (zend_parse_parameters(argc TSRMLS_CC, "ssl|l", &text1, &text1_len, &text2,
+	if (zend_parse_parameters(argc, "ssl|l", &text1, &text1_len, &text2,
 		&text2_len, &numContextLines) == FAILURE)
 	{
 		return;
@@ -118,7 +120,8 @@ PHP_FUNCTION(wikidiff2_do_diff)
 		TableDiff wikidiff2;
 		Wikidiff2::String text1String(text1, text1_len);
 		Wikidiff2::String text2String(text2, text2_len);
-		const Wikidiff2::String & ret = wikidiff2.execute(text1String, text2String, (int)numContextLines, movedParagraphDetectionCutoff());
+		const Wikidiff2::String & ret = wikidiff2.execute(text1String, text2String, (int)numContextLines,
+		movedParagraphDetectionCutoff());
 		COMPAT_RETURN_STRINGL( const_cast<char*>(ret.data()), ret.size());
 	} catch (std::bad_alloc &e) {
 		zend_error(E_WARNING, "Out of memory in wikidiff2_do_diff().");
@@ -137,17 +140,11 @@ PHP_FUNCTION(wikidiff2_inline_diff)
 	char *text1 = NULL;
 	char *text2 = NULL;
 	int argc = ZEND_NUM_ARGS();
-#if PHP_MAJOR_VERSION >= 7
 	size_t text1_len;
 	size_t text2_len;
 	zend_long numContextLines;
-#else
-	int text1_len;
-	int text2_len;
-	long numContextLines;
-#endif
 
-	if (zend_parse_parameters(argc TSRMLS_CC, "ssl", &text1, &text1_len, &text2,
+	if (zend_parse_parameters(argc, "ssl", &text1, &text1_len, &text2,
 		&text2_len, &numContextLines) == FAILURE)
 	{
 		return;
@@ -158,7 +155,8 @@ PHP_FUNCTION(wikidiff2_inline_diff)
 		InlineDiff wikidiff2;
 		Wikidiff2::String text1String(text1, text1_len);
 		Wikidiff2::String text2String(text2, text2_len);
-		const Wikidiff2::String& ret = wikidiff2.execute(text1String, text2String, (int)numContextLines, movedParagraphDetectionCutoff());
+		const Wikidiff2::String& ret = wikidiff2.execute(text1String, text2String, (int)numContextLines,
+		movedParagraphDetectionCutoff());
 		COMPAT_RETURN_STRINGL( const_cast<char*>(ret.data()), ret.size());
 	} catch (std::bad_alloc &e) {
 		zend_error(E_WARNING, "Out of memory in wikidiff2_inline_diff().");
@@ -167,6 +165,42 @@ PHP_FUNCTION(wikidiff2_inline_diff)
 	}
 }
 
+/* {{{ proto string wikidiff2_inline_json_diff(string text1, string text2, int numContextLines)
+ *
+ * Warning: the input text must be valid UTF-8! Do not pass user input directly
+ * to this function.
+ */
+PHP_FUNCTION(wikidiff2_inline_json_diff)
+{
+	char *text1 = NULL;
+	char *text2 = NULL;
+	int argc = ZEND_NUM_ARGS();
+	size_t text1_len;
+	size_t text2_len;
+	zend_long numContextLines;
+
+	if (zend_parse_parameters(argc, "ssl", &text1, &text1_len, &text2,
+		&text2_len, &numContextLines) == FAILURE)
+	{
+		return;
+	}
+
+
+	try {
+		InlineDiffJSON wikidiff2;
+		Wikidiff2::String text1String(text1, text1_len);
+		Wikidiff2::String text2String(text2, text2_len);
+
+		const Wikidiff2::String& ret = wikidiff2.execute(text1String, text2String,
+			(int)numContextLines, movedParagraphDetectionCutoff());
+		COMPAT_RETURN_STRINGL( const_cast<char*>(ret.data()), ret.size());
+	} catch (std::bad_alloc &e) {
+		zend_error(E_WARNING, "Out of memory in wikidiff2_inline_json_diff().");
+	} catch (...) {
+		zend_error(E_WARNING, "Unknown exception in wikidiff2_inline_json_diff().");
+	}
+}
+
 /* {{{ proto string wikidiff2_version()
  */
 PHP_FUNCTION(wikidiff2_version)
@@ -175,5 +209,3 @@ PHP_FUNCTION(wikidiff2_version)
 }
 
 /* }}} */
-
-
